package GFX::Enhancer::AlphaVector;

use parent 'Vector';

sub new {
  my ($class, $bitstring) = @_;
  my $self = $class->SUPER::new($bitstring);
  
}

### diminish

sub lessen_channel {
  my ($self, $less) = @_;

  $self->{bitstring} >>= $less;
}

### enlarge

sub greater_channel {
  my ($self, $greater) = @_;

  $self->{bitstring} <<= $greater;
}

1;
